@@ -28,11 +28,21 @@ from optparse import OptionParser
 import shlex
 
 
+class ExecutableNotInstalledException(Exception):
+    def __init__(self, executable_name):
+        self.executable_name = executable_name
+    def __str__(self):
+        return "Executable not found: %s" % self.executable_name
+
+
 class Executable(object):
     def __init__(self, name):
         self.name = name
-        self.executable_file = self.which(name)
 
+    @property
+    def executable_file(self):
+        return self.which(self.name)
+        
     def which(self, program):
         def is_exe(fpath):
             return os.path.exists(fpath) and os.access(fpath, os.X_OK)
@@ -53,7 +63,7 @@ class Executable(object):
                     if is_exe(candidate):
                         return candidate
 
-        return None
+        raise ExecutableNotInstalledException(program)
 
     def call(self, commandline_arguments, *args, **kwargs):
         return subprocess.call([self.executable_file]+commandline_arguments, *args, **kwargs)
